summaryrefslogtreecommitdiffstats
path: root/client/config/themes.moc.cc
diff options
context:
space:
mode:
Diffstat (limited to 'client/config/themes.moc.cc')
-rw-r--r--client/config/themes.moc.cc72
1 files changed, 36 insertions, 36 deletions
diff --git a/client/config/themes.moc.cc b/client/config/themes.moc.cc
index 111855b..d64c1a9 100644
--- a/client/config/themes.moc.cc
+++ b/client/config/themes.moc.cc
@@ -2,20 +2,20 @@
** IconThemesConfig meta object code from reading C++ file 'themes.h'
**
** Created: Wed Dec 7 20:20:14 2005
-** by: The Qt MOC ($Id: qt/moc_yacc.cpp 3.3.5 edited Sep 2 14:41 $)
+** by: The TQt MOC ($Id: qt/moc_yacc.cpp 3.3.5 edited Sep 2 14:41 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/
#undef QT_NO_COMPAT
#include "themes.h"
-#include <qmetaobject.h>
-#include <qapplication.h>
+#include <tqmetaobject.h>
+#include <tqapplication.h>
#include <private/qucomextra_p.h>
#if !defined(Q_MOC_OUTPUT_REVISION) || (Q_MOC_OUTPUT_REVISION != 26)
#error "This file was generated using the moc from 3.3.5. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif
@@ -24,46 +24,46 @@ const char *IconThemesConfig::className() const
return "IconThemesConfig";
}
-QMetaObject *IconThemesConfig::metaObj = 0;
-static QMetaObjectCleanUp cleanUp_IconThemesConfig( "IconThemesConfig", &IconThemesConfig::staticMetaObject );
+TQMetaObject *IconThemesConfig::metaObj = 0;
+static TQMetaObjectCleanUp cleanUp_IconThemesConfig( "IconThemesConfig", &IconThemesConfig::staticMetaObject );
#ifndef QT_NO_TRANSLATION
-QString IconThemesConfig::tr( const char *s, const char *c )
+TQString IconThemesConfig::tr( const char *s, const char *c )
{
- if ( qApp )
- return qApp->translate( "IconThemesConfig", s, c, QApplication::DefaultCodec );
+ if ( tqApp )
+ return tqApp->translate( "IconThemesConfig", s, c, TQApplication::DefaultCodec );
else
- return QString::fromLatin1( s );
+ return TQString::fromLatin1( s );
}
#ifndef QT_NO_TRANSLATION_UTF8
-QString IconThemesConfig::trUtf8( const char *s, const char *c )
+TQString IconThemesConfig::trUtf8( const char *s, const char *c )
{
- if ( qApp )
- return qApp->translate( "IconThemesConfig", s, c, QApplication::UnicodeUTF8 );
+ if ( tqApp )
+ return tqApp->translate( "IconThemesConfig", s, c, TQApplication::UnicodeUTF8 );
else
- return QString::fromUtf8( s );
+ return TQString::fromUtf8( s );
}
#endif // QT_NO_TRANSLATION_UTF8
#endif // QT_NO_TRANSLATION
-QMetaObject* IconThemesConfig::staticMetaObject()
+TQMetaObject* IconThemesConfig::staticMetaObject()
{
if ( metaObj )
return metaObj;
- QMetaObject* parentObject = KCModule::staticMetaObject();
- static const QUParameter param_slot_0[] = {
- { "item", &static_QUType_ptr, "QListViewItem", QUParameter::In }
+ TQMetaObject* parentObject = KCModule::staticMetaObject();
+ static const TQUParameter param_slot_0[] = {
+ { "item", &static_QUType_ptr, "TQListViewItem", TQUParameter::In }
};
- static const QUMethod slot_0 = {"themeSelected", 1, param_slot_0 };
- static const QUMethod slot_1 = {"installNewTheme", 0, 0 };
- static const QUMethod slot_2 = {"removeSelectedTheme", 0, 0 };
- static const QMetaData slot_tbl[] = {
- { "themeSelected(QListViewItem*)", &slot_0, QMetaData::Protected },
- { "installNewTheme()", &slot_1, QMetaData::Protected },
- { "removeSelectedTheme()", &slot_2, QMetaData::Protected }
+ static const TQUMethod slot_0 = {"themeSelected", 1, param_slot_0 };
+ static const TQUMethod slot_1 = {"installNewTheme", 0, 0 };
+ static const TQUMethod slot_2 = {"removeSelectedTheme", 0, 0 };
+ static const TQMetaData slot_tbl[] = {
+ { "themeSelected(TQListViewItem*)", &slot_0, TQMetaData::Protected },
+ { "installNewTheme()", &slot_1, TQMetaData::Protected },
+ { "removeSelectedTheme()", &slot_2, TQMetaData::Protected }
};
- metaObj = QMetaObject::new_metaobject(
+ metaObj = TQMetaObject::new_metaobject(
"IconThemesConfig", parentObject,
slot_tbl, 3,
0, 0,
@@ -76,35 +76,35 @@ QMetaObject* IconThemesConfig::staticMetaObject()
return metaObj;
}
-void* IconThemesConfig::qt_cast( const char* clname )
+void* IconThemesConfig::tqt_cast( const char* clname )
{
if ( !qstrcmp( clname, "IconThemesConfig" ) )
return this;
- return KCModule::qt_cast( clname );
+ return KCModule::tqt_cast( clname );
}
-bool IconThemesConfig::qt_invoke( int _id, QUObject* _o )
+bool IconThemesConfig::tqt_invoke( int _id, TQUObject* _o )
{
switch ( _id - staticMetaObject()->slotOffset() ) {
- case 0: themeSelected((QListViewItem*)static_QUType_ptr.get(_o+1)); break;
+ case 0: themeSelected((TQListViewItem*)static_QUType_ptr.get(_o+1)); break;
case 1: installNewTheme(); break;
case 2: removeSelectedTheme(); break;
default:
- return KCModule::qt_invoke( _id, _o );
+ return KCModule::tqt_invoke( _id, _o );
}
return TRUE;
}
-bool IconThemesConfig::qt_emit( int _id, QUObject* _o )
+bool IconThemesConfig::tqt_emit( int _id, TQUObject* _o )
{
- return KCModule::qt_emit(_id,_o);
+ return KCModule::tqt_emit(_id,_o);
}
#ifndef QT_NO_PROPERTIES
-bool IconThemesConfig::qt_property( int id, int f, QVariant* v)
+bool IconThemesConfig::tqt_property( int id, int f, TQVariant* v)
{
- return KCModule::qt_property( id, f, v);
+ return KCModule::tqt_property( id, f, v);
}
-bool IconThemesConfig::qt_static_property( QObject* , int , int , QVariant* ){ return FALSE; }
+bool IconThemesConfig::tqt_static_property( TQObject* , int , int , TQVariant* ){ return FALSE; }
#endif // QT_NO_PROPERTIES
@@ -2,20 +2,20 @@
#if !defined(Q_MOC_OUTPUT_REVISION) || (Q_MOC_OUTPUT_REVISION != 26)
#error "This file was generated using the moc from 3.3.5. It"
-#error "cannot be used with the include files from this version of Qt."
+#error "cannot be used with the include files from this version of TQt."
#error "(The moc has changed too much.)"
#endif